pub enum PositionX {
ColumnNumber(usize),
TerminalCenter,
TerminalRight,
PaneBottom,
MousePosition,
StatusLineWindowPosition,
PositionFormat(PositionFormat),
}Expand description
C Both The centre of the terminal R -x The right side of the terminal P Both The bottom left of the pane M Both The mouse position W Both The window position on the status line S -y The line above or below the status line
Variants
ColumnNumber(usize)
TerminalCenter
TerminalRight
PaneBottom
MousePosition
StatusLineWindowPosition
PositionFormat(PositionFormat)